@@ -5,7 +5,7 @@ use Carp ();
 use Exporter::Tidy other => [qw/page start_pager stop_pager/];
 use File::Which;
 use IO::Handle;
-### START Class::Inline ### v0.0.1 Thu Apr 24 15:27:42 2025
+### START Class::Inline ### v0.0.1 Wed Dec  3 10:44:51 2025
 require Carp;
 our ( @_CLASS, $_FIELDS, %_NEW );
 
@@ -13,17 +13,18 @@ sub new {
     my $class = shift;
     my $CLASS = ref $class || $class;
     $_NEW{$CLASS} //= do {
+        my ( %seen, @new, @build );
         my @possible = ($CLASS);
-        if ( defined &{"${CLASS}::DOES"} ) {
-            push @possible, grep !/^${CLASS}$/, $CLASS->DOES('*');
-        }
-        my ( @new, @build );
         while (@possible) {
-            no strict 'refs';
             my $c = shift @possible;
+            no strict 'refs';
             push @new,   $c . '::_NEW'  if exists &{ $c . '::_NEW' };
             push @build, $c . '::BUILD' if exists &{ $c . '::BUILD' };
-            push @possible, @{ $c . '::ISA' };
+            $seen{$c}++;
+            if ( exists &{ $c . '::DOES' } ) {
+                push @possible, grep { not $seen{$_}++ } $c->DOES('*');
+            }
+            push @possible, grep { not $seen{$_}++ } @{ $c . '::ISA' };
         }
         [ [ reverse(@new) ], [ reverse(@build) ] ];
     };
@@ -33,8 +34,7 @@ sub new {
     map { $self->$_($attrs) } @{ $_NEW{$CLASS}->[0] };
     {
         local $Carp::CarpLevel = 3;
-        Carp::carp("OptArgs2::Pager: unexpected argument '$_'")
-          for keys %$attrs;
+        Carp::carp("OptArgs2::Pager: unexpected argument '$_'") for keys %$attrs
     }
     map { $self->$_ } @{ $_NEW{$CLASS}->[1] };
     $self;
@@ -60,7 +60,7 @@ sub encoding {
 }
 
 sub fh {
-    if ( @_ > 1 ) { $_[0]{'fh'} = $_[1]; }
+    if ( @_ > 1 ) { $_[0]{'fh'} = $_[1] }
     $_[0]{'fh'} //= $_FIELDS->{'fh'}->{'default'}->( $_[0] );
 }
 
@@ -75,34 +75,11 @@ sub pager {
 }
 
 sub pid {
-    if ( @_ > 1 ) { $_[0]{'pid'} = $_[1]; }
+    if ( @_ > 1 ) { $_[0]{'pid'} = $_[1] }
     $_[0]{'pid'} // undef;
 }
-
-sub _dump {
-    my $self = shift;
-    my $x    = do {
-        require Data::Dumper;
-        no warnings 'once';
-        local $Data::Dumper::Indent   = 1;
-        local $Data::Dumper::Maxdepth = ( shift // 2 );
-        local $Data::Dumper::Sortkeys = 1;
-        Data::Dumper::Dumper($self);
-    };
-    $x =~ s/.*?{/{/;
-    $x =~ s/}.*?\n$/}/;
-    my $i = 0;
-    my @list;
-    do {
-        @list = caller( $i++ );
-    } until $list[3] eq __PACKAGE__ . '::_dump';
-    warn "$self $x at $list[1]:$list[2]\n";
-}
-
-@_CLASS = grep 1,### END Class::Inline ###
-
-
-  # User provided arguments
+@_CLASS = grep 1,    ### END Class::Inline ###
+                     # User provided arguments
   auto     => { default => 1, },
   encoding => { default => ':utf8', },
   pager    => { default => \&_build_pager, },
@@ -124,7 +101,7 @@ sub _dump {
   },
   ;
 
-our $VERSION  = 'v2.0.14';
+our $VERSION  = 'v2.0.16';
 our @CARP_NOT = (__PACKAGE__);
 
 sub _build_pager {
@@ -230,7 +207,7 @@ OptArgs2::Pager - pipe output to a system (text) pager
 
 =head1 VERSION
 
-v2.0.14 (2025-04-24)
+v2.0.16 (2025-12-05)
 
 =head1 SYNOPSIS
 
